@@ -14,42 +14,6 @@ def apis():
     """Syntropy Networks Command Line Interface."""
 
 
-@apis.command()
-@click.argument("username")
-@click.argument("password", default=None, required=False)
-@syntropy_api
-def login(username, password, api):
-    """Login with username and password.
-
-    Will retrieve access token and print it to stdout. You can provide the password as a second parameter
-    or type it when prompted if the password is not provided.
-
-    \b
-    Example:
-        syntropyctl login MyUser@example.com MyPassword
-
-        \b
-        syntropyctl login MyUser@example.com
-        Password: <type your password here>
-    """
-    if not password:
-        password = click.prompt("Password", default=None, hide_input=True)
-
-    if password is None:
-        click.secho("Password must be provided", err=True, fg="red")
-        raise SystemExit(1)
-
-    payload = {"user_email": username, "user_password": password}
-    api = sdk.AuthApi(api)
-    try:
-        token = api.auth_external_login(body=payload)
-        click.echo(token.access_token)
-    except ApiException as err:
-        click.secho("Login was not successful", err=True, fg="red")
-        click.secho(f"Reason: {str(err)}", err=True, fg="red")
-        raise SystemExit(1)
-
-
 @apis.command()
 @click.option("--skip", default=0, type=int, help="Skip N providers.")
 @click.option("--take", default=128, type=int, help="Take N providers.")
@@ -91,7 +55,7 @@ def get_api_keys(skip, take, json, api):
     """
 
     api = sdk.ApiKeysApi(api)
-    keys = api.index_api_key(skip=skip, take=take).data
+    keys = api.get_api_key(skip=skip, take=take).data
     keys = [key.to_dict() for key in keys]
 
     fields = [
@@ -113,16 +77,14 @@ def get_api_keys(skip, take, json, api):
     type=click.DateTime(formats=["%Y-%m-%d %H:%M:%S"]),
     default=(datetime.now() + timedelta(days=30)).strftime("%Y-%m-%d %H:%M:%S"),
 )
-@click.option("--suspended", "-s", is_flag=True, help="Create a suspended API key.")
 @syntropy_api
-def create_api_key(name, suspended, expires, api):
+def create_api_key(name, expires, api):
     """Create a API key for endpoint agent.
 
     NOTE: Be sure to remember the API key as it will be only available as a result of this command.
     """
     body = {
         "api_key_name": name,
-        "api_key_is_suspended": suspended,
         "api_key_valid_until": expires,
     }
     api = sdk.ApiKeysApi(api)
@@ -157,11 +119,11 @@ def delete_api_key(name, id, yes, api):
     api = sdk.ApiKeysApi(api)
 
     if id is None:
-        keys = api.index_api_key(filter=f"api_key_name:{name}").data
+        keys = api.get_api_key(filter=f"api_key_name:'{name}'").data
         for key in keys:
             if not yes and not confirm_deletion(key.api_key_name, key.api_key_id):
                 continue
-
+            print(key, key.api_key_id)
             api.delete_api_key(key.api_key_id)
             click.secho(
                 f"Deleted API key: {key.api_key_name} (id={key.api_key_id}).",
